@@ -118,9 +118,3 @@ class GoogleTranslator(BaseTranslator):
         @return: list of translations
         """
         return self._translate_batch(batch, **kwargs)
-
-
-if __name__ == "__main__":
-    trans = GoogleTranslator(source="auto", target="zh-CN")
-    res = trans.translate("good")
-    print("translation: ", res)
