@@ -1,6 +1,9 @@
 """
 linguee translator API
 """
+
+__copyright__ = "Copyright (C) 2020 Nidhal Baccouri"
+
 from typing import List, Optional, Union
 
 import requests
@@ -59,7 +62,7 @@ class LingueeTranslator(BaseTranslator):
         if is_input_valid(word, max_chars=50):
             # %s-%s/translation/%s.html
             url = (
-                f"{self._base_url}{self._source}-{self._target}/translation/{word}.html"
+                f"{self._base_url}{self._source}-{self._target}/search/?source={self._source}&query={word}"
             )
             url = requote_uri(url)
             response = requests.get(url, proxies=self.proxies)
@@ -72,7 +75,7 @@ class LingueeTranslator(BaseTranslator):
             soup = BeautifulSoup(response.text, "html.parser")
             elements = soup.find_all(self._element_tag, self._element_query)
             response.close()
-            
+
             if not elements:
                 raise ElementNotFoundInGetRequest(elements)
 
